// Set Goal Position by Sync Write
//  Move position to the full range
//  Since software serial is selected, dynamixel should be use at 57600bps or less.
//  1.select [SOFT]
//  2.compile & download

#include <dxlib.h>
#include <SoftwareSerial.h>

#define MAXNUM 2

DXLIB dxif (true); // select software serial

struct {
  int16_t max, min;
} PosLimit[MAXNUM];

int16_t gpos[MAXNUM], dir[MAXNUM];

void setup() {
  dxif.begin (57143);

  // Get max/min position limit
  for (int i = 0; i < MAXNUM; i++) {
    dxif.ReadWordData (i + 1, 8, (uint16_t *)&PosLimit[i].max, NULL);
    dxif.ReadWordData (i + 1, 6, (uint16_t *)&PosLimit[i].min, NULL);
    dxif.ReadWordData (i + 1, 36, (uint16_t *)&gpos[i], NULL);
    dir[i] = 10;
  }
}

void loop() {
  // Set goal position
  uint8_t ids[MAXNUM];
  int16_t gposs[MAXNUM];

  // Update target value
  for (int i = 0; i < MAXNUM; i++) {
    ids[i] = i + 1;
    gpos[i] += dir[i];
    if (gpos[i] >= PosLimit[i].max)      {
      gpos[i] = PosLimit[i].max;
      dir[i] *= -1;
    } else if (gpos[i] <= PosLimit[i].min) {
      gpos[i] = PosLimit[i].min;
      dir[i] *= -1;
    };
    gposs[i] = gpos[i];
  }
  dxif.WriteSyncWordData (ids, 30, (uint16_t *)gposs, MAXNUM);

  delay (10);
}
